// This file is part of the disk cataloger Wssindex, but was written by a
// 3rd party.  See comments below for author and licensing information.

/*
    File:       sfnt_en.h

    Copyright:  c 1989-1990 by Apple Computer, Inc., all rights reserved.

*/

#ifndef SFNT_ENUNS

typedef enum {
    plat_Unicode,
    plat_Macintosh,
    plat_ISO,
    plat_MS
} sfnt_PlatformEnum;

#ifndef smRoman
typedef enum {
    smRoman,
    smJapanese,
    smTradChinese,
    smChinese = smTradChinese,
    smKorean,
    smArabic,
    smHebrew,
    smGreek,
    smCyrillic,
    smRussian = smCyrillic,
    smRSymbol,
    smDevanagari,
    smGurmukhi,
    smGujarati,
    smOriya,
    smBengali,
    smTamil,
    smTelugu,
    smKannada,
    smMalayalam,
    smSinhalese,
    smBurmese,
    smKhmer,
    smThai,
    smLaotian,
    smGeorgian,
    smArmenian,
    smSimpChinese,
    smTibetan,
    smMongolian,
    smGeez,
    smEthiopic = smGeez,
    smAmharic = smGeez,
    smSlavic,
    smEastEurRoman = smSlavic,
    smVietnamese,
    smExtArabic,
    smSindhi = smExtArabic,
    smUninterp
} sfnt_ScriptEnum;
#endif

typedef enum {
    lang_English,
    lang_French,
    lang_German,
    lang_Italian,
    lang_Dutch,
    lang_Swedish,
    lang_Spanish,
    lang_Danish,
    lang_Portuguese,
    lang_Norwegian,
    lang_Hebrew,
    lang_Japanese,
    lang_Arabic,
    lang_Finnish,
    lang_Greek,
    lang_Icelandic,
    lang_Maltese,
    lang_Turkish,
    lang_Yugoslavian,
    lang_Chinese,
    lang_Urdu,
    lang_Hindi,
    lang_Thai
} sfnt_LanguageEnum;

typedef enum {
    name_Copyright,
    name_Family,
    name_Subfamily,
    name_UniqueName,
    name_FullName,
    name_Version,
    name_Postscript
} sfnt_NameIndex;

typedef long sfnt_TableTag;

#ifdef PC_OS                    /* Constants defined in Intel order */
#define SFNT_SWAPTAG(tag)       (tag)   
#define tag_CharToIndexMap      0x70616d63L       /* 'cmap' */
#define tag_ControlValue        0x20747663L       /* 'cvt ' */
#define tag_Editor0             0x30746465L       /* 'edt0' */
#define tag_Editor1             0x31746465L       /* 'edt1' */
#define tag_Encryption          0x70797263L       /* 'cryp' */
#define tag_FontHeader          0x64616568L       /* 'head' */
#define tag_FontProgram         0x6d677066L       /* 'fpgm' */
#define tag_GlyphDirectory      0x72696467L       /* 'gdir' */
#define tag_GlyphData           0x66796c67L       /* 'glyf' */
#define tag_HoriDeviceMetrics   0x786d6468L       /* 'hdmx' */
#define tag_HoriHeader          0x61656868L       /* 'hhea' */
#define tag_HorizontalMetrics   0x78746d68L       /* 'hmtx' */
#define tag_IndexToLoc          0x61636f6cL       /* 'loca' */
#define tag_Kerning             0x6e72656bL       /* 'kern' */
#define tag_LSTH                0x4853544cL       /* 'LTSH' */
#define tag_LinearThreeshold    0x4853544cL       /* 'LTSH' */
#define tag_MaxProfile          0x7078616dL       /* 'maxp' */
#define tag_NamingTable         0x656d616eL       /* 'name' */
#define tag_OS_2                0x322f534fL       /* 'OS/2' */
#define tag_Postscript          0x74736f70L       /* 'post' */
#define tag_PreProgram          0x70657270L       /* 'prep' */
#else                           /* Constants defined in Motorola order */
#define SFNT_SWAPTAG(tag)       SWAPL(tag)
#define tag_CharToIndexMap      0x636d6170L       /* 'cmap' */
#define tag_ControlValue        0x63767420L       /* 'cvt ' */
#define tag_Editor0             0x65647430L       /* 'edt0' */
#define tag_Editor1             0x65647431L       /* 'edt1' */
#define tag_Encryption          0x63727970L       /* 'cryp' */
#define tag_FontHeader          0x68656164L       /* 'head' */
#define tag_FontProgram         0x6670676dL       /* 'fpgm' */
#define tag_GlyphDirectory      0x67646972L       /* 'gdir' */
#define tag_GlyphData           0x676c7966L       /* 'glyf' */
#define tag_HoriDeviceMetrics   0x68646d78L       /* 'hdmx' */
#define tag_HoriHeader          0x68686561L       /* 'hhea' */
#define tag_HorizontalMetrics   0x686d7478L       /* 'hmtx' */
#define tag_IndexToLoc          0x6c6f6361L       /* 'loca' */
#define tag_Kerning             0x6b65726eL       /* 'kern' */
#define tag_LSTH                0x4c545348L       /* 'LTSH' */
#define tag_LinearThreeshold    0x4c545348L       /* 'LTSH' */
#define tag_MaxProfile          0x6d617870L       /* 'maxp' */
#define tag_NamingTable         0x6e616d65L       /* 'name' */
#define tag_OS_2                0x4f532f32L       /* 'OS/2' */
#define tag_Postscript          0x706f7374L       /* 'post' */
#define tag_PreProgram          0x70726570L       /* 'prep' */
#endif

#endif      /* not sfnt_enums */

#define SFNT_ENUMS
