// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "Dialogs/balancecolumns.h"
//#include "OtherWssi/wssindex.h"

#include <QHeaderView>
#include <QtDebug>
#include <QCoreApplication>

balanceColumns::balanceColumns(QTableView *table)
	{
	whichTable = table;
	colWidthsValid = false;
	}

// This strange construct is to work around a quirk/bug(?) in Qt: if we are called as
// consequence of clicking on a horizontal header, setStretchLastSection(true) doesn't
// work.  Queueing the connection means we go back to the main event loop first.  Maybe
// that's what makes it work.  QCoreApplication::processEvents() does not work.
void balanceColumns::doBalance()
	{
	QMetaObject::invokeMethod(this, "slot_balanceColumnsWorker", Qt::QueuedConnection);
	}

// If table is narrow enough to not have scroll bars displayed,
// expand all columns equally to just fit.  Last column is set
// to auto-expand.
void balanceColumns::slot_balanceColumnsWorker()
	{
	int cols = whichTable->horizontalHeader()->count();
// cols will be zero if we're called before a database has been loaded
	if(cols < 1)
		return;

// Resize all columns to fit contents and record the width of the last column
	int lastCol = cols - 1;
	whichTable->horizontalHeader()->setStretchLastSection(false);
	whichTable->resizeColumnsToContents();
	int lastWidth = whichTable->columnWidth(lastCol);

// Stretch the last column.  If it gets wider, there's some extra width which we
// distribute equally amongst the columns instead of giving it all to the last one.
	whichTable->horizontalHeader()->setStretchLastSection(true);
	whichTable->resizeColumnToContents(lastCol);

	int addWidth = (whichTable->columnWidth(lastCol) - lastWidth) / cols;
	if(addWidth > 0)
		{
		for(int i=0; i<lastCol; i++)
			{
			whichTable->setColumnWidth(i, whichTable->columnWidth(i) + addWidth);
			}
		}
	colWidthsValid = true;
	}
