// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include <QApplication>
#include "Dialogs/mainwindow.h"
#include "OtherWssi/wssindex.h"
#include "OtherWssi/wssiproto.h"
#include "Threads/threadsafe.h"
#include "Threads/querythread.h"
#include "OtherWssi/globalsettings.h"

// Call this to do a query after the Sel and Usesel arrays have been setup.
// Mouse cursor is changed to hourglass during selection

void MainWindow::doSelection()
	{
	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
	threadsafeInit();
	Noselect = 0;
	fileBalance->colWidthsValid = false;
	int nthread = threadsToUse(0);
// No point in the overhead of starting threads if we only have a few files
	if(1 == nthread || Nofile < 1000)
		{
		for(unsigned long k=0; k<Nofile; k++)
			{
			if(!wsreject(k, 0))
				{
				Sortindx[Noselect] = k;
				Noselect++;
				}
			}
		}
	else
		{
		unsigned long *loop_start = new unsigned long[static_cast<unsigned int>(nthread)];
		unsigned long *loop_end = new unsigned long[static_cast<unsigned int>(nthread)];
		loop_start[0] = 0;
		for(int i=1; i<nthread; i++)
			{
			loop_end[i-1] = loop_start[i-1] + Nofile/static_cast<unsigned long>(nthread);
			loop_start[i] = loop_end[i-1] + 1;
			}
		loop_end[nthread-1] = Nofile-1;
		QueryThread **qthread = new QueryThread*[static_cast<unsigned int>(nthread)];
		for(int i=0; i<nthread; i++)
			{
			qthread[i] = new QueryThread();
			qthread[i]->loop_start = loop_start[i];
			qthread[i]->loop_end = loop_end[i];
			qthread[i]->selected = new unsigned long[loop_end[i] - loop_start[i] + 1];
			qthread[i]->ithread = i;
			qthread[i]->start();
			}
		for(int i=0; i<nthread; i++)
			qthread[i]->wait();
		for(int i=0; i<nthread; i++)
			{
			for(unsigned long j=0; j<qthread[i]->select_count; j++)
				{
				Sortindx[Noselect] = qthread[i]->selected[j];
				Noselect++;
				}
			delete qthread[i];
			}
		delete [] loop_start;
		delete [] loop_end;
		delete [] qthread;
		}
	QApplication::restoreOverrideCursor();
	}
