// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"
#include "ui_mainwindow.h"
#include "OtherWssi/globalsettings.h"

#include <QColorDialog>

void MainWindow::checkAlpha(QColor newColor)
	{
	if(newColor.alpha() < 10)
		QMessageBox::information(this, tr("Warning"),
		tr("The chosen color has a small or zero alpha value which"
			" means it will be almost transparent.  If that's not what you want,"
			" change alpha to 255."));
	}

void MainWindow::slot_altColorsToggled()
	{
	FileUseAltColors = !FileUseAltColors;
	useAltColorsAction->setChecked(FileUseAltColors);
	useAltColorsActionTB->setChecked(FileUseAltColors);
	slot_updateDisplay(false);
	}

void MainWindow::slot_evenColorClicked()
	{
	QColor newColor = QColorDialog::getColor(FileRowColor[0], this,
						tr("First row color"), QColorDialog::ShowAlphaChannel);
	if(newColor.isValid())
		{
		FileRowColor[0] = newColor;
		slot_updateDisplay(false);
		}
	checkAlpha(newColor);
	}

void MainWindow::slot_oddColorClicked()
	{
	QColor newColor = QColorDialog::getColor(FileRowColor[1], this,
						tr("Alternate row color"), QColorDialog::ShowAlphaChannel);
	if(newColor.isValid())
		{
		FileRowColor[1] = newColor;
		slot_updateDisplay(false);
		}
	checkAlpha(newColor);
	}

void MainWindow::slot_GridColorClicked()
	{
	QColor newColor = QColorDialog::getColor(FileGridColor, this,
						tr("Grid color"), QColorDialog::ShowAlphaChannel);
	if(newColor.isValid())
		{
		FileGridColor = newColor;
		setFileGridColor();
		slot_updateDisplay(false);
		}
	checkAlpha(newColor);
	}

void MainWindow::setFileGridColor()
	{
	ui->tableView->setStyleSheet(tr("QTableView {gridline-color: rgb(%1,%2,%3);}")
			.arg(FileGridColor.red()).arg(FileGridColor.green()).arg(FileGridColor.blue()));
	}

void MainWindow::slot_pickSkin()
	{
	QSettings settings("WSS-DDC", "Wssindex");
	QString skindir = settings.value("LastSkinDir", "").toString();

	QFileDialog *skindialog = new QFileDialog(this, tr("Select skin"), tr("/"));
	if(skindir.size() > 0)
		skindialog->setDirectory(skindir);

	skindialog->setViewMode(QFileDialog::Detail);
	skindialog->setFileMode(QFileDialog::ExistingFile);
	QStringList filters;
	filters << tr("Style files (*.qss)")
				<< tr("All files (*)");
	skindialog->setNameFilters(filters);
	skindialog->setMinimumWidth(750);

	if(!skindialog->exec())
		return;

	QString skinfile = skindialog->selectedFiles().at(0);
	QFile qssfile(skinfile);
	QString style;
	if(qssfile.open(QFile::ReadOnly))
		{
		QTextStream styleIn(&qssfile);
		style = styleIn.readAll();
		qssfile.close();
		qApp->setStyleSheet(style);
		}
	else
		return;

#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
	static QRegularExpression slash(".*/");
	QRegularExpressionMatch slashmatch = slash.match(skinfile);
	if(slashmatch.hasMatch())
		{
		int lastsep = slashmatch.capturedStart();
#else
	QRegExp slash("/"));
	int lastsep = slash.lastIndexIn(skinfile);
	if(lastsep > 0)
		{
#endif
		skinfile = skinfile.left(lastsep);
		settings.setValue("LastSkinDir", skinfile);
		}
	}

// Note: QApplication::setStyle takes ownership of the style and deletes it when a new
// style is applied while QWidget::setStyle does not do this.
void MainWindow::slot_skinToggled()
	{
	UseModernStyle = !UseModernStyle;
	setAppStyle();

	menuBar()->setStyle(menuBarStyle);
	useDefaultStyleAction->setChecked(!UseModernStyle);
	useDefaultStyleActionTB->setChecked(!UseModernStyle);
	useModernStyleAction->setChecked(UseModernStyle);
	useModernStyleActionTB->setChecked(UseModernStyle);
	}

void MainWindow::slot_pushButtonFitWidthClicked()
	{
	fileBalance->doBalance();
	}
