// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef MESSAGELOGWINDOW_H
#define MESSAGELOGWINDOW_H

#include "OtherWssi/globalsettings.h"

#include <QMainWindow>

namespace Ui
	{
	class MessageLogWindow;
	}

class MainWindow;

class MessageLogWindow : public QMainWindow
	{
	Q_OBJECT

public:
	MessageLogWindow(QWidget *parent);
	~MessageLogWindow() override;
	Ui::MessageLogWindow *ui;

public Q_SLOTS:
	void slot_keyToMl(int key, int modifier);
	void slot_logMessage(QString message);
	void slot_closeLog();
	void slot_wheelToMl(QPoint pos, int delta, Qt::MouseButtons buttons,
						Qt::KeyboardModifiers modifiers, Qt::Orientation orientation);

private Q_SLOTS:
	bool slot_save();
	bool slot_saveAs();
	void slot_wrapToggle();

private:
	void createActions();
	void createMenus();
	void createToolBars();
	bool maybeSave();
	bool saveFile(const QString &fileName);
	void setCurrentFile(const QString &fileName);
	void restoreSettings();
	void updateWrapToggleStatus();
	bool clearIntroText;
	QString curFile;
	QMenu *fileMenu;
	QMenu *editMenu;
	QToolBar *fileToolBar;
	QToolBar *editToolBar;
	QAction *newAct;
	QAction *saveAct;
	QAction *saveAsAct;
	QAction *exitAct;
	QAction *cutAct;
	QAction *copyAct;
	QAction *pasteAct;
	QAction *wrapAct;

Q_SIGNALS:
	void signal_wheelToMl(QPoint, int, Qt::MouseButtons,
										 Qt::KeyboardModifiers, Qt::Orientation);
	};

#endif // MESSAGELOGWINDOW_H
