// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H
#include "OtherWssi/wssindex.h"
#include "OtherWssi/globalsettings.h"
#include "ExtractSubs/extractinfo.h"

#include <QMainWindow>
#include <QCheckBox>
#include <QHBoxLayout>

namespace Ui
	{
	class settingsDialog;
	}

class settingsDialog : public QMainWindow
	{
	Q_OBJECT

public:
	explicit settingsDialog(QWidget *parent = nullptr);
	~settingsDialog() override;

protected:
	void showEvent(QShowEvent *e) override;

private:
	Ui::settingsDialog *ui;
	void restoreWindowSettings();
	void saveWindowSettings();
	void add_centered_widget(QHBoxLayout *layout, QWidget *box);
	void add_extract_title(QGridLayout *glayout, int *row, int type);
	void apply_settings();
	void menu_spacer_lines(QGridLayout *Layout, int i, int *row, bool is_archive);
	void add_toggle_button(QGridLayout *layout, int *row, const char *target_slot, int type);
	void add_box(QGridLayout *glayout, QWidget *tab, int row, QString boxText);
	void addOptions();
	void toggle_arch(int column, int type);
	void toggle_boxes(int boxtype);
	void set_checkboxes();
	void populateGeneralOptions();
	void populateIndexingOptions();
	void populateMemoryOptions();
	QCheckBox *extractContentsBox[NLIBTYPE];
	QCheckBox *extractCommentBox[NLIBTYPE];
	QCheckBox *extractMemberCommentsBox[NLIBTYPE];
	bool checkboxes_created;

private Q_SLOTS:
	void slot_cancelClicked();
	void slot_applyClicked();
	void slot_saveClicked();
	void slot_sortBenchClicked();
	void slot_toggleArchMembers();
	void slot_toggleArchComments();
	void slot_toggleMemberComments();
	void slot_toggleFont();
	void slot_toggleGraphics();
	void slot_toggleSelfextracting();
	void slot_toggleSeComments();
	void slot_toggleSeMemberComments();
	void slot_toggleSound();
	void slot_toggleVideo();
	void slot_validateArchiveSettings();

Q_SIGNALS:
	void signal_saveSettings();
	void signal_updateDisplay(bool);
	};

#endif // SETTINGSDIALOG_H
