// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef TABLEDESIGNDIALOG_H
#define TABLEDESIGNDIALOG_H

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"
#include "3rdparty/clickablelabel.h"

#include <QMainWindow>
#include <QTableWidget>
#include <QSpinBox>
#include <QCheckBox>
#include <QComboBox>
#include <QLabel>

namespace Ui
	{
	class TableDesignDialog;
	}

class TablePreview;

class TableDesignDialog : public QMainWindow
	{
	Q_OBJECT

public:
	explicit TableDesignDialog(MainWindow *parent);
	~TableDesignDialog() override;

private:
	void restoreSettings();
	Ui::TableDesignDialog *td;
	QTableWidget *previewtable;
	TablePreview *tp;
	void setup_preview();
	void set_control_values();
	MainWindow *tdparent;
	void keyPressEvent(QKeyEvent * event) override;

protected:
	void closeEvent(QCloseEvent *event) override;

public:
	QSpinBox *rowspin[NFIELDS], *colspin[NFIELDS],
				*widthspin[NFIELDS], *heightspin[NFIELDS];
	QCheckBox *fieldcheck[NFIELDS];
	QComboBox *justcombo[NFIELDS];
	ClickableLabel *fieldname[NFIELDS];
	bool consistent;

Q_SIGNALS:
	void signal_updateDisplay(bool goToStart);
	void signal_tableRedesign(bool update_display);
	void signal_drawPreview();
	void signal_closePreview(bool save_settings);
	void signal_keyToTable(int, int);

public Q_SLOTS:

private Q_SLOTS:
	void slot_layoutSimple();
	void slot_layoutSimplePv();
	void slot_layoutComplete1r();
	void slot_layoutComplete2r();
	void slot_pushButtonAcceptClicked();
	void slot_pushButtonCancelClicked();
	void slot_pushButtonRestoreClicked();
	void slot_pushButtonSaveClicked();
	void slot_fieldnameLabelClicked();
	};

#endif // TABLEDESIGNDIALOG_H
