// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#ifndef VOLLISTWINDOW_H
#define VOLLISTWINDOW_H

#include "OtherWssi/raise2.h"
#include "Dialogs/balancecolumns.h"

#define NVOLFIELDS 9

// All but SORT_VOL_DUPS may be set negative to reverse sort direction
#define SORT_VOL_DUPS				0
#define SORT_VOL_NAME				1
#define SORT_VOL_USED				2
#define SORT_VOL_FREE				3
#define SORT_VOL_FILES				4
#define SORT_VOL_SUBS				5
#define SORT_VOL_DATE_INDEXED		6
#define SORT_VOL_CATEGORY			7
#define SORT_VOL_COMMENT			8
#define SORT_VOL_EXTRA_INFO		9

#define VOL_DISP_VOLUME				0
#define VOL_DISP_SIZE				1
#define VOL_DISP_FREE				2
#define VOL_DISP_FILES				3
#define VOL_DISP_SUBS				4
#define VOL_DISP_INDEXDATE			5
#define VOL_DISP_CATEGORY			6
#define VOL_DISP_COMMENT			7
#define VOL_DISP_EXTRA_INFO		8

#include <QtGui>
#include <QMainWindow>
#include <QLabel>
#include <QSpinBox>
#include <QWidgetAction>
#include <QTableWidgetItem>

namespace Ui
	{
	class VollistWindow;
	}

class MainWindow;

class VollistWindow : public QMainWindow
	{
	Q_OBJECT

public:
	VollistWindow(QWidget *parent);
	~VollistWindow() override;

private:
	void restoreSettings();
	Ui::VollistWindow *vw;
	void createMenus();
	void createToolbars();
	void checkAlpha(QColor newColor);
	void keyPressEvent(QKeyEvent *event) override;
	void noDotidWarning();
	bool volumeExists(QString volname);
	void contextMenuEvent(QContextMenuEvent *event) override;
	void resizeEvent(QResizeEvent * event) override;
	void setColHeadersAndFont();
	void setVolGridColor();

public:
	QItemSelectionModel *volSelection;

private:
	bool filelistRedrawNeeded;
	int headerVolSortDir[NVOLFIELDS];
	unsigned long volContextClick;
	QLabel *statusMessage;
	unsigned long volStart;
	int topVisibleRow;
	int headerSortDir[NVOLFIELDS];
	QAction *matchFileFontAction;
	QAction *pickFontAction;
	QAction *evenColorAction;
	QAction *oddColorAction;
	QAction *gridColorAction;
	QAction *matchFileColorAction;
	QAction *purgeDupesAction;
	QAction *closeVols;
	QAction *useAltColorsAction;
	QAction *deleteActContext;

	QAction *pickFontActionTB;
	QAction *matchFileFontActionTB;
	QAction *useAltColorsActionTB;
	QAction *evenColorActionTB;
	QAction *oddColorActionTB;
	QAction *gridColorActionTB;
	QAction *matchFileColorActionTB;
	QAction *purgeDupesActionTB;
	QAction *firstActionTB;
	QAction *nextActionTB;
	QAction *previousActionTB;
	QAction *lastActionTB;
	QAction *fitWidthActionTB;
	QAction *nullActionTB;
	QAction *nullActionTB2;
	QAction *exitActionTB;
	QWidgetAction *spinActionTB;

	raise2 *colorPair;
	raise2 *fontPair;

	QTableWidgetItem *colheader[NVOLFIELDS];
	QTimer* resizeTimer;
	balanceColumns *volBalance;

public Q_SLOTS:
	void slot_resizeTimeout();

private Q_SLOTS:
	void slot_volAltColorsToggled();
	void slot_volEvenColorClicked();
	void slot_volOddColorClicked();
	void slot_volGridColorClicked();
	void slot_matchFileColorClicked();
	void slot_volPickFont();
	void slot_matchFileFontClicked();
	void slot_updateVolDisplay(bool goToStart);
	void slot_pushButtonFirstClicked();
	void slot_pushButtonLastClicked();
	void slot_pushButtonNextClicked();
	void slot_pushButtonPreviousClicked();
	void slot_rowHeightSpinboxChanged(int);
	void slot_volRowTracker(int row);
	void slot_pushButtonCloseClicked();
	void slot_volTableClicked(int column);
	void slot_vollistCellEdited(QModelIndex index, QString newValue);
	void slot_pushButtonPurgeClicked();
	void slot_deleteVolumeFromContextMenu();
	void slot_pushButtonFitVolWidthClicked();
	};

#endif // VOLLISTWINDOW_H
