// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "OtherWssi/wssiproto.h"
#include "OtherWssi/wsxxxadd.h"
#include "Dialogs/indexwindow.h"
#include "Non_member_functions/customio.h"

// psfadd - read a postscript font file and add information to wssindex
//	database.  Font name is added as extra info field.
//
//	Note: postscript file may have CR, LF or both as delimiters.

#define MAXLINES 100
#define TEMPBUF_SIZE 4096

int IndexWindow::psfadd(QString path, QString filename, int /* dummy */)
	{
	char tempbuf[TEMPBUF_SIZE];
	char *tptr, *tptr2;
	struct filerec *dr_nofile;
	FILE *fp;

	if(skip_extract(filename))
		return(SKIPPED);

	unsigned long basefile = Nofile - 1;
	int return_code = EXTRACTED_OK;

	if(nullptr == (fp = arc_open(path, filename)))
		return(CANT_OPEN);

	for(int i=0; i<MAXLINES; i++)
		{
		if(nullptr == crlfFgets(tempbuf, TEMPBUF_SIZE, fp))
			goto corrupt;
// Looking for /Fullname (font name)
		tptr = strstr(tempbuf, "/FullName");
		if(!tptr)
			continue;
		if(nullptr == (tptr = strchr(tptr+9, '(')))
			goto corrupt;
		tptr++;
		while (' ' == *tptr)
			tptr++;
		if(nullptr == (tptr2 = strchr(tptr, ')')))
			goto corrupt;
		*tptr2 = EOS;
		trimblnk(tptr);
		strcat(tptr, " postscript font");
		dr_nofile = Dr + basefile;
		dr_nofile->ExtraInfo = tptr;
		setHasExtra(dr_nofile);
		goto norm_ret;
		}

corrupt:
		return_code = CORRUPT;
		Q_EMIT signal_logMessage(tr("%1%2 is corrupted or not a postscript font.")
				.arg(path, filename));

norm_ret:
		fclose(fp);
		return(return_code);
	}
