// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Threads/threadsafe.h"
#include "OtherWssi/globalsettings.h"
#include "Dialogs/mainwindow.h"

#include <QThread>

// freeall - zap an in-core database before reading another or reconfiguring
// Note that this even zaps the "Root" subdirectory stuff
void freeall(void)
	{
	if(Subno > 0)
		delete [] SubDir;
	if(Nofile > 0)
		delete [] Dr;
	if(Diskno > 0)
		delete [] Vrec;
	Subno = Diskno = Nofile = Noselect = NoPlainFiles = 0;
	Maxfiles = Maxsubs = Maxdisks = 0;
	MaxfilesIncMultiplier = MaxsubsIncMultiplier = MaxdisksIncMultiplier = 1;
	mainWindowPtr->statusChanged(false);

	return;
	}

// Set up first subdirectory entry for all root dirs.
//	Always one subdirectory, even if no files.
//	SubDir and SubDisk arrays assumed already allocated.
void rootset(void)
	{
	SubDir[0] = "Root";
	SubDisk[0] = 0;
	Subno = 1;
	return;
	}

// Number of threads to use should be
//   Equal to the number of cores if not otherwise constrained
//   At least one (idealThreadCount returns -1 if number of cores cannot be determined)
//   No more than configured limit
//   No more than array bounds limit (obsolete limit)
// If force > 0, use it as limit
int threadsToUse(int force)
	{
	if(force > 0)
		return force;

	int nthread = QThread::idealThreadCount();
	nthread = qMax(nthread, 1);
	nthread = qMin(nthread, Max_threads);
//	nthread = qMin(nthread, Max_threads);
	return nthread;
	}
