// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include <QtDebug>

// namecomp - compare two file names
//	Fn1 and fn2 are pointers to structures holding the names to be
//	compared.  Comp1 and comp2 indicate which components of the name are
//	to be compared (in order comp1, comp2):
//	comp1,2
//		1 - file name (everything before last dot)
//		2 - file extension (everything after last dot)
//		0 - ignore this component
//
//	Case_sensitivity is set by collator settings
//
//	Returns (similar to strcmp):
//		0 - names equal
//	  <0 - name 1 < name2
//	  >0 - name 1 > name2
//
// Note: QCollator doesn't seem to like QString()
int namecomp(struct filerec *fn1, struct filerec *fn2, int comp1, int comp2)
	{
	QString ext1, ext2, name1, name2;
	int result;

	if(fn1->ExtOffset > 0)
		{
		name1 = fn1->Lfn.left(fn1->ExtOffset-1);
		ext1 = fn1->Lfn.mid(fn1->ExtOffset);
		}
	else
		{
		name1 = fn1->Lfn;
		ext1 = QString("");
		}

	if(fn2->ExtOffset > 0)
		{
		name2 = fn2->Lfn.left(fn2->ExtOffset-1);
		ext2 = fn2->Lfn.mid(fn2->ExtOffset);
		}
	else
		{
		name2 = fn2->Lfn;
		ext2 = QString("");
		}

	if(COMPARE_FILENAME == comp1)
		{
		if(0 != (result = collator->compare(name1, name2)))
			return result;
		}
	if(COMPARE_EXTENSION == comp1)
		{
		if(0 != (result = collator->compare(ext1, ext2)))
			return result;
		}
	if(COMPARE_FILENAME == comp2)
		{
		if(0 != (result = collator->compare(name1, name2)))
			return result;
		}
	if(COMPARE_EXTENSION == comp2)
		{
		if(0 != (result = collator->compare(ext1, ext2)))
			return result;
		}

	return 0;
	}

// fixed_namecomp - this is the same as namecomp except that the file name and
//	extension are separate strings, not part of a filerec structure.
//int fixed_namecomp(const QString name1, const QString ext1, const struct filerec *fn2,
//						 int comp1, int comp2, bool case_sens)
//	{
//	QString text1, ext2, tname1, name2;
//	int result;

//	tname1 = name1;
//	text1 = ext1;
//	if(fn2->ExtOffset > 0)
//		{
//		name2 = fn2->Lfn.left(fn2->ExtOffset-1);
//		ext2 = fn2->Lfn.mid(fn2->ExtOffset);
//		}
//	else
//		{
//		name2 = fn2->Lfn;
//		ext2 = QString();
//		}

//	if(case_sens)
//		{
//		tname1.toLower();
//		name2.toLower();
//		text1.toLower();
//		ext2.toLower();
//		}

//	if(COMPARE_FILENAME == comp1)
//		{
////		if(0 != (result = QString::localeAwareCompare(tname1, name2)))
//		if(0 != (result = qstringCompareFunction(tname1, name2)))
//			return result;
//		}
//	if(COMPARE_EXTENSION == comp1)
//		{
////		if(0 != (result = QString::localeAwareCompare(text1, ext2)))
//		if(0 != (result = qstringCompareFunction(text1, ext2)))
//			return result;
//		}
//	if(COMPARE_FILENAME == comp2)
//		{
////		if(0 != (result = QString::localeAwareCompare(tname1, name2)))
//		if(0 != (result = qstringCompareFunction(tname1, name2)))
//			return result;
//		}
//	if(COMPARE_EXTENSION == comp2)
//		{
////		if(0 != (result = QString::localeAwareCompare(text1, ext2)))
//		if(0 != (result = qstringCompareFunction(text1, ext2)))
//			return result;
//		}

//	return 0;
//	}
