// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "ExtractSubs/extractinfo.h"
#include "OtherWssi/globalsettings.h"

#undef EXTERN
#define EXTERN
#include "Threads/threadsafe.h"

// Initialize the QRegExps that are constant
//void threadsafe_init_constants()
//	{
//// U+300 through U+36F is the Unicode Combining Diacritical Marks block
//	QRegExp diamarks_master = QRegExp(QFA("[\\x0300-\\x036f]"));
//// German eszett (looks like beta) is ligature for ss
//	QRegExp eszett_master = QRegExp(QFA("[\\x00df]"));

//	for(int i=0; i<Max_threads; i++)
//		{
//		diamarksCopy[i] = diamarks_master;
//		eszettCopy[i] = eszett_master;
//		}
//	}

void threadsafeInit()
	{
// U+300 through U+36F is the Unicode Combining Diacritical Marks block
	QRegExp diamarks_master = QRegExp(QFA("[\\x0300-\\x036f]"));
// German eszett (looks like beta) is ligature for ss
	QRegExp eszett_master = QRegExp(QFA("[\\x00df]"));

	diamarksCopy.resize(Max_threads);
	eszettCopy.resize(Max_threads);
// This loop could start at regexpsAllocated instead of 0
	for(int i=0; i<Max_threads; i++)
		{
		diamarksCopy[i] = diamarks_master;
		eszettCopy[i] = eszett_master;
		}
	ComparcCopy.resize(Max_threads);
	CompcatCopy.resize(Max_threads);
	CompcomCopy.resize(Max_threads);
	CompextraCopy.resize(Max_threads);
	CompdskCopy.resize(Max_threads);
	CompsubCopy.resize(Max_threads);
	MatchNameCopy.resize(Max_threads);
	ZipNameCopy.resize(Max_threads);

	int oldsize = nameRegexpCopy.size();
	nameRegexpCopy.resize(Max_threads);
	for(int i=oldsize; i<Max_threads; i++)
		nameRegexpCopy[i] = QVector<QRegExp>(NLIBTYPE);

	for(int i=0; i<Max_threads; i++)
		{
		ComparcCopy[i] = QRegExp(Comparc);
		ComparcCopy[i].setPatternSyntax(QRegExp::Wildcard);
		ComparcCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		CompcatCopy[i] = QRegExp(Compcat);
		CompcatCopy[i].setPatternSyntax(QRegExp::Wildcard);
		CompcatCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		CompcomCopy[i] = QRegExp(Compcom);
		CompcomCopy[i].setPatternSyntax(QRegExp::Wildcard);
		CompcomCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		CompextraCopy[i] = QRegExp(Compextra);
		CompextraCopy[i].setPatternSyntax(QRegExp::Wildcard);
		CompextraCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		CompdskCopy[i] = QRegExp(Compdsk);
		CompdskCopy[i].setPatternSyntax(QRegExp::Wildcard);
		CompdskCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		CompsubCopy[i] = QRegExp(Compsub);
		CompsubCopy[i].setPatternSyntax(QRegExp::Wildcard);
		CompsubCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		MatchNameCopy[i] = QRegExp(MatchName);
		MatchNameCopy[i].setPatternSyntax(QRegExp::Wildcard);
		MatchNameCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		ZipNameCopy[i] = QRegExp(ZipName);
		ZipNameCopy[i].setPatternSyntax(QRegExp::Wildcard);
		ZipNameCopy[i].setCaseSensitivity(Qt::CaseInsensitive);

		for(int j=0; j<NLIBTYPE; j++)
			{
			nameRegexpCopy[i][j] = Extract[j].nameRegexp;
			}
		}
	}
