// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include <QLineEdit>
#include <QtDebug>
#include <QStringListModel>

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"

// IF this value is changed, also update the tooltip in simplequerydialog.cpp
#define MAX_SEARCH_HISTORY 25

void updateSearchHistory(QString searchText)
	{
// If current text is empty, do nothing
// If already in history, move to beginning of list.  Move is done by
//	copy text, delete row, add row at top, set top row to saved value.
// Else add at beginning of list
	if(searchText.isEmpty())
		return;
	QStringListModel *model = mainWindowPtr->searchModel;
	int loc = model->stringList().indexOf(searchText);
// If new search term maches first one in list, nothing needs to be done
	if(0 == loc)
		return;
	if(loc >= 0)
		{
		QString moveToTop = model->stringList().at(loc);
		model->removeRow(loc);
		model->insertRow(0);
		model->setData(model->index(0), moveToTop);
		return;
		}
	else
		{
		model->insertRow(0);
		model->setData(model->index(0), searchText);
		}

// Delete the last row if we've exceeded the limit of MAX_SEARCH_HISTORY
	int historyRows = model->rowCount();
	if(historyRows > MAX_SEARCH_HISTORY)
		model->removeRow(historyRows - 1);
	}
