// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include <stdio.h>
#ifndef EOS
	#define EOS '\0'
#endif

// wgets - get a newline terminated string from a stream
//	This routine is similar to fgets, except that it will read maxbuf
//	rather than maxbuf-1 characters if a newline is not found sooner,
//	and the returned string will never include a newline character.
//	Also, if strip is true, the character is and'ed with 7F so that things
//	like WordStar files can be read.  This is an old option which is not
//	used anymore.  The returned string will always be null terminated.
// Reaching end of file before a newline is considered an error.

char *wgets(char *string, unsigned short maxbuf, FILE *fp, bool strip)
	{
	int cc;
	int mask = strip ? 0x7f : 0xff;

	for(unsigned int j=0; j<maxbuf; j++)
		{
		if((cc = fgetc(fp)) == EOF)
			{
			string[j] = EOS;
			return(nullptr);
			}
		if((string[j] = static_cast<char>(cc & mask)) == '\n')
			{
			string[j] = EOS;
			return(string);
			}
		}
// If we fall out of this loop, the input line was too long for the provided buffer.
// Silently flush the rest of the line.
//	fprintf(stderr, "wgets could not read entire string, file position = %ld", ftell(fp));
	string[maxbuf-1] = EOS;

	for(;;)
		{
		if(EOF == (cc = fgetc(fp)))
			break;
		if('\n' == cc)
			return(string);
		}
// We hit EOF without finding a newline.  That's an error.
	return(nullptr);
	}
