// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/raise2.h"
#include "Dialogs/mainwindow.h"

#include <QEvent>
#include <QToolButton>
#include <QMenu>

raise2::raise2(QObject *parent, QToolBar *whichBar, QIcon icon,
	QString tooltip1, QString tooltip2, const char *method, bool queue) : QObject(parent)
	{
	widebutton = new QToolButton(static_cast<QWidget *>(parent));
	pulldown  = new QToolButton(static_cast<QWidget *>(parent));
	menu = new QMenu(static_cast<QWidget *>(parent));
	widebutton->setPopupMode(QToolButton::InstantPopup);
	pulldown->setPopupMode(QToolButton::InstantPopup);
	pulldown->setMaximumWidth(DOWN_ARROW_WIDTH);

	widebutton->setToolTip(tooltip1);
	pulldown->setToolTip(tooltip2);
	widebutton->setIcon(icon);
	widebutton->installEventFilter(this);
	pulldown->installEventFilter(this);
	whichBar->addWidget(widebutton);
	if(queue)
		connect(widebutton, SIGNAL(clicked()), parent, method, Qt::QueuedConnection);
	else
		connect(widebutton, SIGNAL(clicked()), parent, method);

	QWidgetAction *actionTB = new QWidgetAction(whichBar);
	actionTB->setDefaultWidget(pulldown);
	whichBar->addAction(actionTB);
	pulldown->setMenu(menu);
	}

bool raise2::eventFilter(QObject *obj, QEvent *event)
	{
	QString raisedBorder = "QToolButton { border-width: 1px; border-style: solid;"
		"margin: 0px; padding-left: 1px; padding-right: 1px; padding-top: 1px; padding-bottom: 0px;"
		"border-top-color: #ffffff; border-left-color: #ffffff;"
		"border-right-color: #808080; border-bottom-color: #808080; }";
	QString loweredBorder = "";

	if(event->type() == QEvent::Enter || event->type() == QEvent::Leave)
		{
		if(!widebutton->isEnabled())
			return true;
		if(widebutton->underMouse() || pulldown->underMouse())
			{
			widebutton->setStyleSheet(raisedBorder);
			pulldown->setStyleSheet(raisedBorder);
			}
		else
			{
			widebutton->setStyleSheet(loweredBorder);
			pulldown->setStyleSheet(loweredBorder);
			}
		return true;
		}
	return QObject::eventFilter(obj, event);
	}
