// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "OtherWssi/wssindex.h"
#include "Dialogs/mainwindow.h"

// removews - remove a disk from wssindex database
//	Returns true if failed (disk not found), false if removal successful.
//
//	start_index is where to start looking for volume name.  Normally this is
//	zero, but for removing duplicates, it can be set to the index of the
//	volume to be removed and the duplicate will not be seen.
//
//	This routine used to be called remove, but that conflicts with an
//	ANSI standard name for a file deletion routine.

// Note: this is used when a disk is deleted from the volume list or
// when purging duplicates.  For a disk removed because it is replaced
// during indexing see IndexWindow::delete_disk

bool MainWindow::removews(QString name, unsigned long start_index)
	{
	unsigned long nfremove=0;
	for(unsigned long i=start_index; i<Diskno; i++)
		{
		struct diskrec *vrec_i = Vrec + i;
		if(name != vrec_i->VolName)
			continue;
		Diskno--;
		Q_EMIT signal_diskListChanged();

// Loop over files.  If file is on deleted disk, increment count of deleted
//	files and free storage for any comment or category.  If file follows
//	deleted disk, move file record back, adjust volume number field and
//	subdir field for archive members (which actually has index of containing
//	archive file)
		for(unsigned long j=0; j<Nofile; j++)
			{
			struct filerec	*dr_j = Dr + j;
			struct filerec	*dr_jnremov = Dr + j - nfremove;
			Dr[j-nfremove] = Dr[j];
			if(dr_j->Volno > i)
				{
				dr_jnremov->Volno--;
				if(inArc(dr_j))
					dr_jnremov->Subdirno -= nfremove;
				}
			else if(dr_j->Volno == i)
				{
				nfremove++;
				}
			}

		Nofile -= nfremove;

// Move disk records back one starting from first after deleted disk
		for(unsigned long j=i; j<Diskno; j++)
			{
			Vrec[j] = Vrec[j+1];
			Vrec[j].firstOnDisk -= nfremove;
			}

// Loop over subdirectories.  Move disk numbers in SubDisk array back.  If
//	subdirectory is on deleted disk, increment count of deleted subdirectories
//	and free up storage.  Adjust disk number for subdirectories following
//	deleted subdirectories.
		unsigned long first=0;
		unsigned long nsremove = 0;
		for(unsigned long k=1; k<Subno; k++)
			{
			SubDisk[k-nsremove] = SubDisk[k];
			SubDir[k-nsremove] = SubDir[k];
			if(SubDisk[k] == i)
				{
				nsremove++;
				if(first == 0)
					first = k;
				}
			else
				if(SubDisk[k] > i)
					SubDisk[k-nsremove] -= 1;
			}
		NoPlainFiles -= nfremove - nsremove - 1;

// If any subdirectories have been removed, loop over files again adjusting
//	subdirectory numbers for true subdirectories (not archive members).
		if(nsremove > 0)
			{
			for(unsigned long j=0; j<Nofile; j++)
				{
				struct filerec	*dr_j = Dr + j;
				if(inArc(dr_j))
					continue;
				if(dr_j->Subdirno >= first)
					dr_j->Subdirno -= nsremove;
				}
			}

		Subno -= nsremove;
		statusChanged(true);
		return false;
		}
	return true;
	}
