// This file is part of the disk cataloger Wssindex.  Wssindex is copyright
// 1985-2021 by Robert W. Babcock and WSS Division of DDC.  Effective 2010,
// Wssindex is distributed under the terms of the GNU General Public
// License.  Contact the author at wssddc@wssddc.com or see the project web
// page at <https://www.wssddc.com/wssindex/>.
//
// Wssindex uses the open source Qt toolkit from the Qt Project (qt-project.org)
// and The Qt Company (www.qt.io).
//
// Wssindex is free software: you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation, either version 3 of the License, or (at your
// option) any later version.
//
// Wssindex is distributed in the hope that it will be useful, but WITHOUT
// ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
//
// You should have received a copy of the GNU General Public License along
// with Wssindex.  If not, see <https://www.gnu.org/licenses/>.

#include "searchcompleter.h"
#include "Dialogs/mainwindow.h"

#include <QCompleter>
#include <QLineEdit>
#include <QKeyEvent>
#include <QtDebug>
#include <QAbstractItemView>
#include <QStringListModel>

SearchCompleter::SearchCompleter(QWidget *parent) : QLineEdit(parent)
	{
	model = mainWindowPtr->searchModel;
	}

void SearchCompleter::keyPressEvent(QKeyEvent *e)
	{
	QCompleter *c = this->completer();
	if(!c)
		{
		QLineEdit::keyPressEvent(e);
		return;
		}

	switch(e->key())
		{
		case Qt::Key_Delete:
			{
			int currentRow = c->popup()->currentIndex().row();
// If nothing is highlighted in the popup, currentRow will be -1
// and we don't have to do anything.
			if(currentRow < 0)
				break;
			c->setCurrentRow(currentRow);
//			QString currentComp = c->currentCompletion();

// Remove from the completer model
			model->removeRow(currentRow);

// Highlight the item below the one we just deleted, or the new last item if
// we just deleted the last item.  If nothing matches the text typed in,
// the completer popup goes away.
			int newRow = std::min(currentRow, c->completionCount() - 1);
			if(newRow >= 0)
				c->popup()->setCurrentIndex(c->completionModel()->index(newRow, 0));
			c->complete();
			return;
			}

// Return/Enter don't need special handling

// Down arrow pops up all possible completions if no completion is highlighted.
// Down arrow doesn't make it to here if completer is already displayed.
		case Qt::Key_Down:
			{
			c->setCompletionPrefix(QString());
			c->complete();
			}
			break;

		default:
			break;
		}

	QLineEdit::keyPressEvent(e);
	return;
	}
