# -------------------------------------------------
# Qt project file for Wssindex using MinGW or VC++
# -------------------------------------------------
TARGET = WssIndex
TEMPLATE = app

# Version for MediaInfo as well as ZenLib and Zlib which are bundled with it
# Also need to set this in 3rdparty\otherversion.h
MI_VERSION = 22.09

# Needed OpenSSL files are included with MinGW but not Visual Studio
# Also see defines in 3rdparty\otherversion.h
OPENSSL_VERSION = 1.1.1o

# 7zip version is also in 3rdparty\otherversion.h
# The 7zip version also needs to be updated for #includes in Extractors\7zipadd.cpp
# 7zip sources used here come from the lzma sdk
ZIP7_VER = 2201

# Old QCustomplot may be better because it doesn't need printsupport.
# If QCPVER is changed, touch Workarounds\forcecompile.h to force
# rebuild of routines that depend on QCPVER.

# NSIS file for building installers searches for string QCPVER equals
# to determine whether Qt5PrintSupport.dll is needed in MinGW builds.
QCPVER = 2.1

isEqual(QCPVER, 1.x) {
# Don't let QCustomPlot generate a need for Qt5PrintSupport.dll
	DEFINES += QT_NO_PRINTER QT_NO_PRINTDIALOG QT_NO_PRINTPREVIEWWIDGET
	DEFINES += OLDQCP
	FORMS += Forms/sortbenchdialog-old.ui
	HEADERS += 3rdparty/qcustomplot-old.h
	SOURCES += 3rdparty/qcustomplot-old.cpp \
	} else {
	QT *= printsupport
	FORMS += Forms/sortbenchdialog.ui
	HEADERS += 3rdparty/qcustomplot.h
	SOURCES += 3rdparty/qcustomplot.cpp \
	}

FORMS += \
	Forms/archivesdialog.ui \
	Forms/filetypedialog.ui \
	Forms/fullsortdialog.ui \
	Forms/indexingdialog.ui \
	Forms/indextimefilter.ui \
	Forms/indexwindow.ui \
	Forms/mainwindow.ui \
	Forms/messagelogwindow.ui \
	Forms/namesquerydialog.ui \
	Forms/rangequerydialog.ui \
	Forms/settingsdialog.ui \
	Forms/simplequerydialog.ui \
	Forms/simplesortdialog.ui \
	Forms/specialquerydialog.ui \
	Forms/tabledesigndialog.ui \
	Forms/tablepreview.ui \
	Forms/textviewer.ui \
	Forms/vollistwindow.ui \
	Forms/welcome.ui

HEADERS += \
	3rdparty/7zip-$$ZIP7_VER/7z.h \
	3rdparty/7zip-$$ZIP7_VER/7zAlloc.h \
	3rdparty/7zip-$$ZIP7_VER/7zBuf.h \
	3rdparty/7zip-$$ZIP7_VER/7zCrc.h \
	3rdparty/7zip-$$ZIP7_VER/7zFile.h \
	3rdparty/7zip-$$ZIP7_VER/7zTypes.h \
	3rdparty/7zip-$$ZIP7_VER/Bcj2.h \
	3rdparty/7zip-$$ZIP7_VER/Bra.h \
	3rdparty/7zip-$$ZIP7_VER/Compiler.h \
	3rdparty/7zip-$$ZIP7_VER/CpuArch.h \
	3rdparty/7zip-$$ZIP7_VER/Delta.h \
	3rdparty/7zip-$$ZIP7_VER/Lzma2Dec.h \
	3rdparty/7zip-$$ZIP7_VER/LzmaDec.h \
	3rdparty/7zip-$$ZIP7_VER/Precomp.h \
	3rdparty/InfoZip/unzip.h \
	3rdparty/MediaInfo/MediaInfo.h \
	3rdparty/MediaInfo/MediaInfo_Const.h \
	3rdparty/ZenLib/Conf.h \
	3rdparty/ZenLib/Utils.h \
	3rdparty/ZenLib/Ztring.h \
	3rdparty/ZenLib/int128u.h \
	3rdparty/clickablelabel.h \
	3rdparty/focuswatcher.h \
	3rdparty/fscdefs.h \
	3rdparty/helpmenustyle.h \
	3rdparty/otherversion.h \
	3rdparty/qsvgaspect.h \
	3rdparty/qtablewidgetoverride.h \
	3rdparty/sfnt.h \
	3rdparty/sfnt_en.h \
	3rdparty/unrar.h \
	3rdparty/windowsmodernstyle.h \
	Dialogs/archivesdialog.h \
	Dialogs/balancecolumns.h \
	Dialogs/fadeanimation.h \
	Dialogs/filetypedialog.h \
	Dialogs/fullsortdialog.h \
	Dialogs/indexingdialog.h \
	Dialogs/indextimefilter.h \
	Dialogs/indexwindow.h \
	Dialogs/mainwindow.h \
	Dialogs/messagelogwindow.h \
	Dialogs/namesquerydialog.h \
	Dialogs/rangequerydialog.h \
	Dialogs/settingsdialog.h \
	Dialogs/simplequerydialog.h \
	Dialogs/simplesortdialog.h \
	Dialogs/sortbenchdialog.h \
	Dialogs/specialquerydialog.h \
	Dialogs/tabledesigndialog.h \
	Dialogs/tablepreview.h \
	Dialogs/textviewer.h \
	Dialogs/vollistwindow.h \
	ExtractSubs/extractinfo.h \
	ModelView/autotooltipdelegate.h \
	ModelView/diskbox.h \
	ModelView/filetablemodel.h \
	ModelView/volcombomodel.h \
	ModelView/voltablemodel.h \
	Non_member_functions/customio.h \
	OtherWssi/globalsettings.h \
	OtherWssi/initialpos.h \
	OtherWssi/pinlist.h \
	OtherWssi/pinmenu.h \
	OtherWssi/raise2.h \
	OtherWssi/searchcompleter.h \
	OtherWssi/tablelayout.h \
	OtherWssi/thousandsspinbox.h \
	OtherWssi/versioninfo.h \
	OtherWssi/wssindex.h \
	OtherWssi/wssiproto.h \
	OtherWssi/wsxxxadd.h \
	Threads/binsearchthread.h \
	Threads/fillbinthread.h \
	Threads/mergesortthread.h \
	Threads/querythread.h \
	Threads/threadsafe.h \
	Workarounds/forcecompile.h \
	Workarounds/menushvalues.include \
	Workarounds/submenuproxy.h

SOURCES += \
	3rdparty/7zip-$$ZIP7_VER/7zAlloc.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zArcIn.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zBuf.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zCrc.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zCrcOpt.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zDec.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zFile.cpp \
	3rdparty/7zip-$$ZIP7_VER/7zStream.cpp \
	3rdparty/7zip-$$ZIP7_VER/Bcj2.cpp \
	3rdparty/7zip-$$ZIP7_VER/Bra.cpp \
	3rdparty/7zip-$$ZIP7_VER/Bra86.cpp \
	3rdparty/7zip-$$ZIP7_VER/BraIA64.cpp \
	3rdparty/7zip-$$ZIP7_VER/CpuArch.cpp \
	3rdparty/7zip-$$ZIP7_VER/Delta.cpp \
	3rdparty/7zip-$$ZIP7_VER/Lzma2Dec.cpp \
	3rdparty/7zip-$$ZIP7_VER/LzmaDec.cpp \
	3rdparty/InfoZip/explode.cpp \
	3rdparty/InfoZip/inflate.cpp \
	3rdparty/InfoZip/unshrink.cpp \
	3rdparty/clickablelabel.cpp \
	3rdparty/ejectnt.cpp \
	3rdparty/focuswatcher.cpp \
	3rdparty/qsvgaspect.cpp \
	3rdparty/qtablewidgetoverride.cpp \
	3rdparty/rtriminplace.cpp \
	3rdparty/windowsmodernstyle.cpp \
	Dialogs/archivesdialog.cpp \
	Dialogs/balancecolumns.cpp \
	Dialogs/doselection.cpp \
	Dialogs/dosort.cpp \
	Dialogs/fadeanimation.cpp \
	Dialogs/filetypedialog.cpp \
	Dialogs/fullsortdialog.cpp \
	Dialogs/gpl3license.cpp \
	Dialogs/indexingdialog.cpp \
	Dialogs/indextimefilter.cpp \
	Dialogs/indexwindow.cpp \
	Dialogs/indexwindow_edit.cpp \
	Dialogs/indexwindow_filter.cpp \
	Dialogs/indexwindow_index.cpp \
	Dialogs/indexwindow_init.cpp \
	Dialogs/main_csvexport.cpp \
	Dialogs/main_events.cpp \
	Dialogs/main_fieldedit.cpp \
	Dialogs/main_filemenu.cpp \
	Dialogs/main_fontmenu.cpp \
	Dialogs/main_helpmenu.cpp \
	Dialogs/main_indexmenu.cpp \
	Dialogs/main_init.cpp \
	Dialogs/main_navigation.cpp \
	Dialogs/main_querymenu.cpp \
	Dialogs/main_settingsmenu.cpp \
	Dialogs/main_sortmenu.cpp \
	Dialogs/main_stylemenu.cpp \
	Dialogs/main_tabledesign.cpp \
	Dialogs/main_volumesmenu.cpp \
	Dialogs/mainwindow.cpp \
	Dialogs/messagelogwindow.cpp \
	Dialogs/namesquerydialog.cpp \
	Dialogs/otherlicense.cpp \
	Dialogs/purgedup.cpp \
	Dialogs/rangequerydialog.cpp \
	Dialogs/settingsdialog.cpp \
	Dialogs/simplequerydialog.cpp \
	Dialogs/simplesortdialog.cpp \
	Dialogs/sortbenchdialog.cpp \
	Dialogs/specialquerydialog.cpp \
	Dialogs/tabledesigndialog.cpp \
	Dialogs/tablepreview.cpp \
	Dialogs/textviewer.cpp \
	Dialogs/vollistwindow.cpp \
	Dialogs/welcome.cpp \
	ExtractSubs/comarch.cpp \
	ExtractSubs/extraarch.cpp \
	ExtractSubs/extractinfo.cpp \
	ExtractSubs/nopath.cpp \
	ExtractSubs/swap.cpp \
	Extractors/7zipadd.cpp \
	Extractors/arcadd.cpp \
	Extractors/arjadd.cpp \
	Extractors/bmpadd.cpp \
	Extractors/cabadd.cpp \
	Extractors/gifadd.cpp \
	Extractors/hapadd.cpp \
	Extractors/hypadd.cpp \
	Extractors/jpgadd.cpp \
	Extractors/lbradd.cpp \
	Extractors/lhaadd.cpp \
	Extractors/mediainfosoundadd.cpp \
	Extractors/mediainfovideoadd.cpp \
	Extractors/movieadd.cpp \
	Extractors/mp3add.cpp \
	Extractors/pcxadd.cpp \
	Extractors/pngadd.cpp \
	Extractors/psfadd.cpp \
	Extractors/raradd.cpp \
	Extractors/soundadd.cpp \
	Extractors/tgaadd.cpp \
	Extractors/tifadd.cpp \
	Extractors/ttfadd.cpp \
	Extractors/zipadd.cpp \
	Extractors/zooadd.cpp \
	ModelView/autotooltipdelegate.cpp \
	ModelView/diskbox.cpp \
	ModelView/filetablemodel.cpp \
	ModelView/volcombomodel.cpp \
	ModelView/voltablemodel.cpp \
	Non_member_functions/customio.cpp \
	Non_member_functions/forceonscreen.cpp \
	Non_member_functions/formattedsize.cpp \
	Non_member_functions/freeall.cpp \
	Non_member_functions/isTableDesignConsistent.cpp \
	Non_member_functions/lastdot.cpp \
	Non_member_functions/lfnpiece.cpp \
	Non_member_functions/match.cpp \
	Non_member_functions/mergesort.cpp \
	Non_member_functions/msdos-time.cpp \
	Non_member_functions/namecomp.cpp \
	Non_member_functions/numbrkey.cpp \
	Non_member_functions/qstring_compare.cpp \
	Non_member_functions/reject.cpp \
	Non_member_functions/widerCombo.cpp \
	Non_member_functions/selectAllUnsorted.cpp \
	Non_member_functions/threadsafe_init.cpp \
	Non_member_functions/trimblnk.cpp \
	Non_member_functions/unbad.cpp \
	Non_member_functions/update_prev_sel.cpp \
	Non_member_functions/updatesearchhistory.cpp \
	Non_member_functions/wgets.cpp \
	Non_member_functions/wputs.cpp \
	Non_member_functions/wssicomp.cpp \
	Non_member_functions/wssvcomp.cpp \
	OtherWssi/getwss.cpp \
	OtherWssi/incfile.cpp \
	OtherWssi/main.cpp \
	OtherWssi/makeid.cpp \
	OtherWssi/mydrop.cpp \
	OtherWssi/pinlist.cpp \
	OtherWssi/pinmenu.cpp \
	OtherWssi/putwss.cpp \
	OtherWssi/raise2.cpp \
	OtherWssi/removews.cpp \
	OtherWssi/searchcompleter.cpp \
	OtherWssi/setdefaultvalues.cpp \
	OtherWssi/simpleconf.cpp \
	Threads/binsearchthread.cpp \
	Threads/fillbinthread.cpp \
	Threads/mergesortthread.cpp \
	Threads/querythread.cpp \
	Workarounds/aes-missing.cpp

QT *= network
QT *= svg

CONFIG -= qml_debug
CONFIG -= qtquickcompiler

CONFIG *= warn_on

# Qt Creator 4.11.0 requires this for MinGW builds
CONFIG *= debug_and_release
CONFIG *= debug_and_release_target

Debug: {
	CONFIG += console
	DEFINES += DEBUG_VER
	DR = debug
	}
Release: {
	DR = release
	CONFIG -= separate_debug_info
	CONFIG -= force_debug_info
	}

#DEFINES += QT_NO_CAST_FROM_ASCII \
#	QT_NO_CAST_TO_ASCII \
DEFINES += \
	QT_USE_FAST_CONCATENATION \
	QT_USE_FAST_OPERATOR_PLUS
RESOURCES += images.qrc

# Disable use of any Qt function deprecated in 5.8.x or earlier
# Any higher setting breaks windowsmodernstyle.cpp
# Deprecated functions may still generate warnings
DEFINES += QT_DISABLE_DEPRECATED_BEFORE=0x0508ff

win32	{
	OTHER_FILES += Wssindex.rc
	RC_FILE = Wssindex.rc
	}

greaterThan(QT_MAJOR_VERSION, 4) {
	QT *= widgets
	INCLUDEPATH += $$PWD
	}

# A few known cases where Qt bugs break things
# Point version upgrades fix these
isEqual(QT_VERSION, 5.6.0) {
	error("Don't use Qt 5.6.0, pinmenu won't work")
	}
isEqual(QT_VERSION, 5.14.0) {
	error("Don't use Qt 5.14.0, indexing animations won't scale properly")
	}

equals(QT_ARCH, x86_64) {
	BITNESS = 64
	RARBIT = 64
	ARCH = X64
	QMAKE_CXXFLAGS += -DVER_64_BIT
	} else {
	BITNESS = 32
	RARBIT = ""
	ARCH = X86
	}

COMPDIR = $$(QTDIR)
contains(COMPDIR, ".*mingw.*") {
	COMP = MinGW
	DEFINES += BUILT_WITH_MinGW
	LIBEXT = a
	}
contains(COMPDIR, ".*msvc2013.*") {
	COMP = VC2013
	DEFINES += BUILT_WITH_MSVC12
	LIBEXT = lib
	}
contains(COMPDIR, ".*msvc2015.*") {
	COMP = VC2015
	DEFINES += BUILT_WITH_MSVC14
	LIBEXT = lib
# This marks the application as supporting long paths, not supported by Visual Studio 2013
	QMAKE_POST_LINK += mt -nologo -manifest $$PWD/LongPathAware.xml -updateresource:$$OUT_PWD/$$DR/$${TARGET}.exe $$escape_expand(\n\t)
	}
contains(COMPDIR, ".*msvc2017.*") {
	COMP = VC2017
	DEFINES += BUILT_WITH_MSVC15
 	QMAKE_CXXFLAGS += /std:c++latest
	LIBEXT = lib
	QMAKE_POST_LINK += mt -nologo -manifest $$PWD/LongPathAware.xml -updateresource:$$OUT_PWD/$$DR/$${TARGET}.exe $$escape_expand(\n\t)
	}
contains(COMPDIR, ".*msvc2019.*") {
	COMP = VC2019
	DEFINES += BUILT_WITH_MSVC16
	QMAKE_CXXFLAGS += /std:c++latest
	LIBEXT = lib
	QMAKE_POST_LINK += mt -nologo -manifest $$PWD/LongPathAware.xml -updateresource:$$OUT_PWD/$$DR/$${TARGET}.exe $$escape_expand(\n\t)
	}

# I use different drive letters on my desktop and laptop
DRIVE_LETTER = $$section(_PRO_FILE_PWD_,  :, 0, 0)

CORRECT_PATH = $$lower("$$DRIVE_LETTER:/Builds/Projects/$$TARGET/$$BITNESS-bit-$$COMP-$$QT_VERSION")
USED_PATH = $$clean_path($$lower($$OUT_PWD))
!equals(USED_PATH, "$$CORRECT_PATH") {
	message("QTDIR = $$QTDIR")
	error("Build path is $$USED_PATH, should be $$CORRECT_PATH")
	}

# Visual C++ needs user32.lib, MinGW must not have it
# Use the safe CRT library routines where no source code changes are needed,
# disable warnings for others.
win32-msvc* {
	equals(BITNESS, 32) { QMAKE_LFLAGS *= /LARGEADDRESSAWARE }
	LIBS *= user32.lib
	DEFINES += _CRT_SECURE_CPP_OVERLOAD_STANDARD_NAMES=1
	DEFINES += _CRT_SECURE_NO_WARNINGS
	CONFIG += no_batch
	}

# Following fix is obsolete, instead add C:\Program Files (x86)\Windows Kits\10\bin\10.0.15063.0\x86
# or later version to end of system path.  Otherwise, link may be done when not needed.
# This fixes unable to find rc.exe error with Visual Studio 2015
#	QMAKE_EXTRA_TARGETS += customtarget1
#	customtarget1.target = dummy
#	customtarget1.commands = set PATH=C:\Program Files (x86)\Windows Kits\10\bin\10.0.15063.0\\$$ARCH\;$(PATH)
#	PRE_TARGETDEPS += dummy

win32-g++ {
# Win/2K or greater required, only XP or higher tested
	DEFINES += _WIN32_WINNT=0x0500
	equals(BITNESS, 32) { QMAKE_LFLAGS *= -Wl,--large-address-aware }
	}

INCLUDEPATH += $$PWD/3rdparty

win32-msvc* {
#	LIBS += -LC:/Comp/OpenSSL-Win64-$$OPENSSL_VERSION/lib/VC/static/ -llibeay32MD
	LIBS += -LC:/Comp/OpenSSL-Win64-$$OPENSSL_VERSION/lib/VC/static/
	}

# To allow unrar DLLs to be found when running from Qt Creator, enable the default checkbox
# "Add build library to search path" and add UnRar to LIBS.
LIBS += -L$$DRIVE_LETTER:/Builds/UnRar

equals(LIBEXT, lib) { LIB_PREFIX = ""}
equals(LIBEXT, a) { LIB_PREFIX = "lib"}

LIBS += $$DRIVE_LETTER:/Builds/UnRar/UnRAR$${RARBIT}.lib
LIBS += -L$$DRIVE_LETTER:/Builds/Projects/mediainfolib-$$MI_VERSION/$$BITNESS-bit-$$COMP-$$QT_VERSION/$$DR/ -l$${LIB_PREFIX}mediainfolib-$${MI_VERSION}
LIBS += -L$$DRIVE_LETTER:/Builds/Projects/ZenLib-$$MI_VERSION/$$BITNESS-bit-$$COMP-$$QT_VERSION/$$DR/ -l$${LIB_PREFIX}zenlib-$${MI_VERSION}
LIBS += -L$$DRIVE_LETTER:/Builds/Projects/Zlib-$$MI_VERSION/$$BITNESS-bit-$$COMP-$$QT_VERSION/$$DR/ -l$${LIB_PREFIX}zlib-$${MI_VERSION}

# Verify that needed libraries exist, but not whether they are up-to-date
PRE_TARGETDEPS += $$DRIVE_LETTER:/Builds/Projects/mediainfolib-$$MI_VERSION/$$BITNESS-bit-$$COMP-$$QT_VERSION/$$DR/$${LIB_PREFIX}mediainfolib-$${MI_VERSION}.$$LIBEXT
PRE_TARGETDEPS += $$DRIVE_LETTER:/Builds/Projects/ZenLib-$$MI_VERSION/$$BITNESS-bit-$$COMP-$$QT_VERSION/$$DR/$${LIB_PREFIX}zenlib-$${MI_VERSION}.$$LIBEXT
PRE_TARGETDEPS += $$DRIVE_LETTER:/Builds/Projects/Zlib-$$MI_VERSION/$$BITNESS-bit-$$COMP-$$QT_VERSION/$$DR/$${LIB_PREFIX}zlib-$${MI_VERSION}.$$LIBEXT

DISTFILES += \
	 LongPathAware.xml \
	 OtherWssi/optionsVarlist.include \
	 OtherWssi/optionsVarlistTop.include \
	 OtherWssi/optionsVarlistVol.include
